summaryrefslogtreecommitdiffstats
path: root/konqueror/konq_guiclients.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /konqueror/konq_guiclients.cc
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konqueror/konq_guiclients.cc')
-rw-r--r--konqueror/konq_guiclients.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/konqueror/konq_guiclients.cc b/konqueror/konq_guiclients.cc
index 196a046ca..316c88254 100644
--- a/konqueror/konq_guiclients.cc
+++ b/konqueror/konq_guiclients.cc
@@ -230,7 +230,7 @@ TQPtrList<KAction> ToggleViewGUIClient::actions() const
void ToggleViewGUIClient::slotToggleView( bool toggle )
{
- TQString serviceName = TQString::tqfromLatin1( sender()->name() );
+ TQString serviceName = TQString::fromLatin1( sender()->name() );
bool horizontal = m_mapOrientation[ serviceName ];
@@ -240,7 +240,7 @@ void ToggleViewGUIClient::slotToggleView( bool toggle )
{
KonqView *childView = viewManager->splitWindow( horizontal ? Qt::Vertical : Qt::Horizontal,
- TQString::tqfromLatin1( "Browser/View" ),
+ TQString::fromLatin1( "Browser/View" ),
serviceName,
!horizontal /* vertical = make it first */);
@@ -299,13 +299,13 @@ void ToggleViewGUIClient::slotToggleView( bool toggle )
void ToggleViewGUIClient::saveConfig( bool add, const TQString &serviceName )
{
// This is used on konqueror's startup....... so it's never used, since
// the K menu only tqcontains calls to kfmclient......
// Well, it could be useful again in the future.
// Currently, the profiles save this info.
TQStringList toggableViewsShown = KonqSettings::toggableViewsShown();
if (add)
{
- if ( !toggableViewsShown.tqcontains( serviceName ) )
+ if ( !toggableViewsShown.contains( serviceName ) )
toggableViewsShown.append(serviceName);
}
else
@@ -299,13 +299,13 @@ void ToggleViewGUIClient::slotToggleView( bool toggle )
{
// This is used on konqueror's startup....... so it's never used, since
- // the K menu only tqcontains calls to kfmclient......
+ // the K menu only contains calls to kfmclient......
// Well, it could be useful again in the future.
// Currently, the profiles save this info.